Debug Toolbar 
================

Flask-MAB includes experimental support for `Flask-Debugtoolbar <http://flask-debugtoolbar.readthedocs.org/en/latest/>`_.

In order to enable MAB support, be sure to add :code:`"flask.ext.mab.debug_panels.BanditDebugPanel"` to your :code:`"DEBUG_TB_PANELS"` configuration key.

.. image:: _static/debug_toolbar.png 
